@@ -7,10 +7,13 @@ use axum_debug::debug_handler;
 struct A;
 
 #[async_trait]
-impl FromRequest for A {
+impl<B> FromRequest<B> for A
+where
+    B: Send + 'static,
+{
     type Rejection = ();
 
-    async fn from_request(_req: &mut RequestParts) -> Result<Self, Self::Rejection> {
+    async fn from_request(_req: &mut RequestParts<B>) -> Result<Self, Self::Rejection> {
         unimplemented!()
     }
 }
